.. Case Study notebooks

.. toctree::
   :maxdepth: 2
   :caption: Case Studies

   Effect of membership rewards program <dowhy_example_effect_of_memberrewards_program>
   Understanding hotel booking cancellations <DoWhy-The Causal Story Behind Hotel Booking Cancellations>
   

